A cli TagSpaces_ client, especially geared towards `The Secret Weapon`_
approach to Getting Things Done.

.. _TagSpaces: https://www.tagspaces.org/
.. _The Secret Weapon: http://www.thesecretweapon.org/the-secret-weapon-manifesto/manifesto-part-1-the-issue
